//
//  Conformance.swift
//  PreferencesEditor
//
//  Created by Don McBrien on 13/04/2021.
//

import Foundation

protocol CustomFieldProtocol {
   var simpleString: String { get }
   init?(_ string: String) // already conformed to by most types
}

extension Double: CustomFieldProtocol {
   var simpleString: String {
      // basic format and strip away tailing "0"'s
      var str = String(format: "%f", self)
      while str.last == "0" { str.removeLast() }
      if str.last == "." { str += "0" }
      return str
   }
}

extension Int: CustomFieldProtocol {
   var simpleString: String { String(format: "%d", self) }
}

//extension Array: CustomFieldProtocol where Element: CustomFieldProtocol {
//   var simpleString: String { "\(self)" }
//   init?(_ string: String) { return nil }
//}
//
extension ClosedRange: CustomFieldProtocol where Bound == Int {
   init?(_ string: String) {
      let parts = string.components(separatedBy: "...").filter { !$0.isEmpty }
      if parts.count != 2 { return nil }
      if let from = Int(parts[0]) {
         if let to = Int(parts[1]) {
            self = from ... to
         } else { return nil }
      } else { return nil }
    }
   
   var simpleString: String { return "\(self)" }
}

extension String: CustomFieldProtocol {
   var simpleString: String { self }
}

extension Probability: CustomFieldProtocol {
   init?(_ string: String) {
      if let v = Double(string) { value = v / 100.0 }
      else { return nil }
   }
   var simpleString: String { value.simpleString }
}
