//
//  CustomFieldStyle.swift
//  PreferencesEditor
//
//  Created by Don McBrien on 13/04/2021.
//

import Foundation
import SwiftUI

//MARK: - Custom Modifiers
struct CustomFieldStyle: ViewModifier {
   var foregroundColor: Color?
   var width: CGFloat?
   
  func body(content: Content) -> some View {
    content
      .foregroundColor(foregroundColor)
      .background(Color.white)
      .padding(EdgeInsets(top: 8, leading: 16, bottom: 8, trailing: 16))
      .overlay(RoundedRectangle(cornerRadius: 4)
                  .stroke(lineWidth: 2))
      .shadow(color: Color.gray.opacity(0.4), radius: 2, x: 1, y: 2)
      .frame(width: width, alignment: .trailing)
      .padding(5)
  }
}

extension View {
   func customFieldStyle(foregroundColor: Color? = .black, width: CGFloat? = 120) -> some View {
    ModifiedContent(
      content: self,
      modifier: CustomFieldStyle(foregroundColor: foregroundColor, width: width)
    )
  }
}
