//
//  CustomRow.swift
//  PreferencesEditor
//
//  Created by Don McBrien on 13/04/2021.
//

import SwiftUI

struct CustomRow<T: CustomFieldProtocol>: View {
   // Packages a value to be edited, usually in a CustomField, providing a label and
   // some styling modifiers
   // By examining the type T in a switch, it can determine that a collection of related
   // values are being edited and instead call an appropriate CustomButton with its
   // validators
   
   @EnvironmentObject var editorEnvironment: PreferencesEditorEnvironment
   var title: String = ""
   @Binding var value: T { didSet { self.string = value.simpleString } }
   var fieldValidator: ((T) -> Bool)? = nil
   var collectionValidator: ((T) -> Bool)? = nil

   @State private var string: String = ""
   
   var body: some View {
      HStack {
         Group {
            if title.count > 0 { Text(title) }
            else { EmptyView() }
         }.frame(width: editorEnvironment.titleWidth, alignment: editorEnvironment.titleAlignment)

         CustomField(value: $value, fieldValidator: fieldValidator)
      }
   }
}


//MARK: - Previews
struct CustomRow_Previews: PreviewProvider {
   @EnvironmentObject var editor: PreferencesEditorEnvironment
   static var previews: some View {
      VStack {
         CustomRow(title: "Real:",
                     value: .constant(123.45))
         CustomRow(title: "Integer:",
                     value: .constant(67))
      }
   }
}
