//
//  PreferencesEditor.swift
//  Shared
//
//  Created by Don McBrien on 13/04/2021.
//

import SwiftUI

struct PreferencesEditor: View {
   @ObservedObject var viewModel = PreferencesViewModel()
   @StateObject var editorEnvironment = PreferencesEditorEnvironment()
   
   var body: some View {
      ScrollView {
         VStack {
            Spacer()
            Text("Parameters").font(.largeTitle)
            Spacer()
         }
         
         LazyVStack {
            CustomRow(title: "String (of min length):",
                      value: $viewModel.string,
                      fieldValidator: { str in (str.count > 3) }).padding(5)
            
            CustomRow(title: "Real Number (any):",
                      value: $viewModel.number).padding(5)
            
            CustomRow(title: "Probability(0% ≦ p ≦ 100%):",
                      value: $viewModel.probability,
                      fieldValidator: { prob in (prob.value <= 1.0) && (prob.value >= 0.0) }).padding(5)
            
            CustomRow(title: "Integer (Negative):",
                      value: $viewModel.integer,
                      fieldValidator: { neg in (neg < 0) }).padding(5)
         }
         
         
         VStack {
            ForEach(viewModel.intArray.indices, id: \.self) { idx in
               CustomRow(title: "Int Array[\(idx)]:",
                         value: self.$viewModel.intArray[idx]).padding(5)
            }
            
            ForEach(viewModel.doubleArray.indices, id: \.self) { idx in
               CustomRow(title: "Double Array[\(idx)]:",
                         value: self.$viewModel.doubleArray[idx]).padding(5)
            }
         }
         
         VStack {
            Spacer()
            Button("Run") { viewModel.runModel() }
               .disabled(!editorEnvironment.commit)
            Spacer()
         }
      }
      .environmentObject(editorEnvironment)
      .padding()
   }
}

struct PreferencesEditor_Previews: PreviewProvider {
   static var previews: some View {
      PreferencesEditor()
   }
}
